CallModerationWarningEvent class

Constructors

CallModerationWarningEvent({required String callCid, required DateTime createdAt, Map<String, Object> custom = const {}, required String message, String type = 'call.moderation_warning', required String userId})
Returns a new CallModerationWarningEvent instance.

Properties

callCid String
getter/setter pair
createdAt DateTime
getter/setter pair
custom Map<String, Object>
Custom data associated with the moderation action
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
message String
The warning message
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of event: "call.moderation_warning" in this case
getter/setter pair
userId String
The user ID who is receiving the warning
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CallModerationWarningEvent?
Returns a new CallModerationWarningEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CallModerationWarningEvent>
mapFromJson(dynamic json) Map<String, CallModerationWarningEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CallModerationWarningEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.