CallStatsParticipantCounts class
Constructors
-
CallStatsParticipantCounts({int? averageJitterMs, int? averageLatencyMs, int? callEventCount, int? cqScore, required int liveSessions, int? maxFreezesDurationMs, required int participants, required int peakConcurrentSessions, required int peakConcurrentUsers, required int publishers, required int sessions, required int sfusUsed, int? totalParticipantDuration})
-
Returns a new CallStatsParticipantCounts instance.
Properties
-
averageJitterMs
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
averageLatencyMs
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
callEventCount
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
cqScore
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
liveSessions
↔ int
-
getter/setter pair
-
maxFreezesDurationMs
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
participants
↔ int
-
getter/setter pair
-
peakConcurrentSessions
↔ int
-
getter/setter pair
-
peakConcurrentUsers
↔ int
-
getter/setter pair
-
publishers
↔ int
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
↔ int
-
getter/setter pair
-
sfusUsed
↔ int
-
getter/setter pair
-
totalParticipantDuration
↔ int?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair