CallUserFeedbackSubmittedEvent class

Constructors

CallUserFeedbackSubmittedEvent({required String callCid, required DateTime createdAt, Map<String, Object> custom = const {}, required int rating, String? reason, String? sdk, String? sdkVersion, required String sessionId, String type = 'call.user_feedback_submitted', required UserResponse user})
Returns a new CallUserFeedbackSubmittedEvent instance.

Properties

callCid String
getter/setter pair
createdAt DateTime
getter/setter pair
custom Map<String, Object>
Custom data provided by the user
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
rating int
The rating given by the user (1-5)
getter/setter pair
reason String?
The reason provided by the user for the rating
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdk String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
sdkVersion String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
sessionId String
Call session ID
getter/setter pair
type String
The type of event, "call.user_feedback" in this case
getter/setter pair
user UserResponse
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CallUserFeedbackSubmittedEvent?
Returns a new CallUserFeedbackSubmittedEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CallUserFeedbackSubmittedEvent>
mapFromJson(dynamic json) Map<String, CallUserFeedbackSubmittedEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CallUserFeedbackSubmittedEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.