FeedsPreferencesResponse class

Constructors

FeedsPreferencesResponse({String? comment, String? commentReaction, Map<String, String> customActivityTypes = const {}, String? follow, String? mention, String? reaction})
Returns a new FeedsPreferencesResponse instance.

Properties

comment String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
commentReaction String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
customActivityTypes Map<String, String>
getter/setter pair
follow String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
mention String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
reaction String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FeedsPreferencesResponse?
Returns a new FeedsPreferencesResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FeedsPreferencesResponse>
mapFromJson(dynamic json) Map<String, FeedsPreferencesResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FeedsPreferencesResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.