GetCallSessionParticipantStatsDetailsResponse class
Properties
-
callId
↔ String
-
getter/setter pair
-
callSessionId
↔ String
-
getter/setter pair
-
callType
↔ String
-
getter/setter pair
-
duration
↔ String
-
Duration of the request in milliseconds
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
publisher
↔ ParticipantSeriesPublisherStats?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriber
↔ ParticipantSeriesSubscriberStats?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
timeframe
↔ ParticipantSeriesTimeframe?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
user
↔ ParticipantSeriesUserStats?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
userId
↔ String
-
getter/setter pair
-
userSessionId
↔ String
-
getter/setter pair