decode method

IngressSourceRequestFpsEnum? decode(
  1. dynamic data, {
  2. bool allowNull = true,
})

Decodes a data to a IngressSourceRequestFpsEnum.

If allowNull is true and the data cannot be decoded successfully, then null is returned. However, if allowNull is false and the data cannot be decoded successfully, then an UnimplementedError is thrown.

The allowNull is very handy when an API changes and a new enum value is added or removed, and users are still using an old app with the old code.

Implementation

IngressSourceRequestFpsEnum? decode(dynamic data, {bool allowNull = true}) {
  if (data != null) {
    switch (data) {
      case 30:
        return IngressSourceRequestFpsEnum.number30;
      case 60:
        return IngressSourceRequestFpsEnum.number60;
      default:
        if (!allowNull) {
          throw ArgumentError('Unknown enum value to decode: $data');
        }
    }
  }
  return null;
}