IngressStoppedEvent class

Constructors

IngressStoppedEvent({required String callCid, required DateTime createdAt, required String ingressStreamId, String type = 'ingress.stopped', required String userId})
Returns a new IngressStoppedEvent instance.

Properties

callCid String
getter/setter pair
createdAt DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ingressStreamId String
Unique identifier for the stream
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of event: "ingress.stopped" in this case
getter/setter pair
userId String
User who was streaming
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) IngressStoppedEvent?
Returns a new IngressStoppedEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<IngressStoppedEvent>
mapFromJson(dynamic json) Map<String, IngressStoppedEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<IngressStoppedEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.