OwnCapability class

All possibility of string to use

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) OwnCapability?
listFromJson(dynamic json, {bool growable = false}) List<OwnCapability>

Constants

blockUsers → const OwnCapability
changeMaxDuration → const OwnCapability
createCall → const OwnCapability
createReaction → const OwnCapability
enableNoiseCancellation → const OwnCapability
endCall → const OwnCapability
joinBackstage → const OwnCapability
joinCall → const OwnCapability
joinEndedCall → const OwnCapability
kickUser → const OwnCapability
muteUsers → const OwnCapability
pinForEveryone → const OwnCapability
readCall → const OwnCapability
removeCallMember → const OwnCapability
screenshare → const OwnCapability
sendAudio → const OwnCapability
sendClosedCaptionsCall → const OwnCapability
sendVideo → const OwnCapability
startBroadcastCall → const OwnCapability
startClosedCaptionsCall → const OwnCapability
startFrameRecordCall → const OwnCapability
startIndividualRecordCall → const OwnCapability
startRawRecordCall → const OwnCapability
startRecordCall → const OwnCapability
startTranscriptionCall → const OwnCapability
stopBroadcastCall → const OwnCapability
stopClosedCaptionsCall → const OwnCapability
stopFrameRecordCall → const OwnCapability
stopIndividualRecordCall → const OwnCapability
stopRawRecordCall → const OwnCapability
stopRecordCall → const OwnCapability
stopTranscriptionCall → const OwnCapability
updateCall → const OwnCapability
updateCallMember → const OwnCapability
updateCallPermissions → const OwnCapability
updateCallSettings → const OwnCapability
values → const List<OwnCapability>
List of all possible values in this OwnCapability.