ParticipantSeriesTimeframe class

Constructors

ParticipantSeriesTimeframe({required int maxPoints, required DateTime since, required int stepSeconds, required DateTime until})
Returns a new ParticipantSeriesTimeframe instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
maxPoints int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
since DateTime
getter/setter pair
stepSeconds int
getter/setter pair
until DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ParticipantSeriesTimeframe?
Returns a new ParticipantSeriesTimeframe instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ParticipantSeriesTimeframe>
mapFromJson(dynamic json) Map<String, ParticipantSeriesTimeframe>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ParticipantSeriesTimeframe>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.