ParticipantSeriesTrackMetrics class
Constructors
-
ParticipantSeriesTrackMetrics({String? codec, String? label, Map<String, List<List<double>>> metrics = const {}, Map<String, MetricDescriptor> metricsMeta = const {}, List<String> metricsOrder = const [], String? rid, Map<String, List<MetricThreshold>> thresholds = const {}, required String trackId, String? trackType})
-
Returns a new ParticipantSeriesTrackMetrics instance.
Properties
-
codec
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
label
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
metrics
↔ Map<String, List<List<double>>>
-
getter/setter pair
-
metricsMeta
↔ Map<String, MetricDescriptor>
-
getter/setter pair
-
metricsOrder
↔ List<String>
-
getter/setter pair
-
rid
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
thresholds
↔ Map<String, List<MetricThreshold>>
-
getter/setter pair
-
trackId
↔ String
-
getter/setter pair
-
trackType
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair