ParticipantSeriesUserStats class

Constructors

ParticipantSeriesUserStats({Map<String, List<List<double>>> metrics = const {}, Map<String, MetricDescriptor> metricsMeta = const {}, List<String> metricsOrder = const [], Map<String, List<MetricThreshold>> thresholds = const {}})
Returns a new ParticipantSeriesUserStats instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
metrics Map<String, List<List<double>>>
getter/setter pair
metricsMeta Map<String, MetricDescriptor>
getter/setter pair
metricsOrder List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thresholds Map<String, List<MetricThreshold>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ParticipantSeriesUserStats?
Returns a new ParticipantSeriesUserStats instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ParticipantSeriesUserStats>
mapFromJson(dynamic json) Map<String, ParticipantSeriesUserStats>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ParticipantSeriesUserStats>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.