ProductVideoApi class

Constructors

ProductVideoApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptCall(String type, String id) Future<AcceptCallResponse?>
Accept Call
acceptCallWithHttpInfo(String type, String id) Future<Response>
Accept Call
blockUser(String type, String id, BlockUserRequest blockUserRequest) Future<BlockUserResponse?>
Block user on a call
blockUserWithHttpInfo(String type, String id, BlockUserRequest blockUserRequest) Future<Response>
Block user on a call
collectUserFeedback(String type, String id, CollectUserFeedbackRequest collectUserFeedbackRequest) Future<CollectUserFeedbackResponse?>
Collect user feedback
collectUserFeedbackWithHttpInfo(String type, String id, CollectUserFeedbackRequest collectUserFeedbackRequest) Future<Response>
Collect user feedback
createDevice(CreateDeviceRequest createDeviceRequest) Future<DurationResponse?>
Create device
createDeviceWithHttpInfo(CreateDeviceRequest createDeviceRequest) Future<Response>
Create device
createGuest(CreateGuestRequest createGuestRequest) Future<CreateGuestResponse?>
Create Guest
createGuestWithHttpInfo(CreateGuestRequest createGuestRequest) Future<Response>
Create Guest
deleteCall(String type, String id, DeleteCallRequest deleteCallRequest) Future<DeleteCallResponse?>
Delete Call
deleteCallWithHttpInfo(String type, String id, DeleteCallRequest deleteCallRequest) Future<Response>
Delete Call
deleteDevice(String id) Future<DurationResponse?>
Delete device
deleteDeviceWithHttpInfo(String id) Future<Response>
Delete device
deleteRecording(String type, String id, String session, String filename) Future<DeleteRecordingResponse?>
Delete recording
deleteRecordingWithHttpInfo(String type, String id, String session, String filename) Future<Response>
Delete recording
deleteTranscription(String type, String id, String session, String filename) Future<DeleteTranscriptionResponse?>
Delete transcription
deleteTranscriptionWithHttpInfo(String type, String id, String session, String filename) Future<Response>
Delete transcription
endCall(String type, String id) Future<EndCallResponse?>
End call
endCallWithHttpInfo(String type, String id) Future<Response>
End call
getCall(String type, String id, {String? connectionId, int? membersLimit, bool? ring, bool? notify, bool? video}) Future<GetCallResponse?>
Get Call
getCallParticipantSessionMetrics(String type, String id, String session, String user, String userSession, {DateTime? since, DateTime? until}) Future<GetCallParticipantSessionMetricsResponse?>
Get call participant session metrics
getCallParticipantSessionMetricsWithHttpInfo(String type, String id, String session, String user, String userSession, {DateTime? since, DateTime? until}) Future<Response>
Get call participant session metrics
getCallReport(String type, String id, {String? sessionId}) Future<GetCallReportResponse?>
Get call report
getCallReportWithHttpInfo(String type, String id, {String? sessionId}) Future<Response>
Get call report
getCallSessionParticipantStatsDetails(String callType, String callId, String session, String user, String userSession, {String? since, String? until, int? maxPoints}) Future<GetCallSessionParticipantStatsDetailsResponse?>
Get call session participant stats details
getCallSessionParticipantStatsDetailsWithHttpInfo(String callType, String callId, String session, String user, String userSession, {String? since, String? until, int? maxPoints}) Future<Response>
Get call session participant stats details
getCallSessionParticipantStatsTimeline(String callType, String callId, String session, String user, String userSession, {String? startTime, String? endTime, List<String>? severity}) Future<QueryCallSessionParticipantStatsTimelineResponse?>
Get participant timeline events
getCallSessionParticipantStatsTimelineWithHttpInfo(String callType, String callId, String session, String user, String userSession, {String? startTime, String? endTime, List<String>? severity}) Future<Response>
Get participant timeline events
getCallStatsMap(String callType, String callId, String session, {DateTime? startTime, DateTime? endTime, bool? excludePublishers, bool? excludeSubscribers, bool? excludeSfus}) Future<QueryCallStatsMapResponse?>
Map call participants by location
getCallStatsMapWithHttpInfo(String callType, String callId, String session, {DateTime? startTime, DateTime? endTime, bool? excludePublishers, bool? excludeSubscribers, bool? excludeSfus}) Future<Response>
Map call participants by location
getCallWithHttpInfo(String type, String id, {String? connectionId, int? membersLimit, bool? ring, bool? notify, bool? video}) Future<Response>
Get Call
getEdges() Future<GetEdgesResponse?>
Get Edges
getEdgesWithHttpInfo() Future<Response>
Get Edges
getOrCreateCall(String type, String id, GetOrCreateCallRequest getOrCreateCallRequest, {String? connectionId}) Future<GetOrCreateCallResponse?>
Get or create a call
getOrCreateCallWithHttpInfo(String type, String id, GetOrCreateCallRequest getOrCreateCallRequest, {String? connectionId}) Future<Response>
Get or create a call
goLive(String type, String id, GoLiveRequest goLiveRequest) Future<GoLiveResponse?>
Set call as live
goLiveWithHttpInfo(String type, String id, GoLiveRequest goLiveRequest) Future<Response>
Set call as live
joinCall(String type, String id, JoinCallRequest joinCallRequest, {String? connectionId}) Future<JoinCallResponse?>
Join call
joinCallWithHttpInfo(String type, String id, JoinCallRequest joinCallRequest, {String? connectionId}) Future<Response>
Join call
kickUser(String type, String id, KickUserRequest kickUserRequest) Future<KickUserResponse?>
Kick user from a call
kickUserWithHttpInfo(String type, String id, KickUserRequest kickUserRequest) Future<Response>
Kick user from a call
listDevices() Future<ListDevicesResponse?>
List devices
listDevicesWithHttpInfo() Future<Response>
List devices
listRecordings(String type, String id) Future<ListRecordingsResponse?>
List recordings
listRecordingsWithHttpInfo(String type, String id) Future<Response>
List recordings
listTranscriptions(String type, String id) Future<ListTranscriptionsResponse?>
List transcriptions
listTranscriptionsWithHttpInfo(String type, String id) Future<Response>
List transcriptions
muteUsers(String type, String id, MuteUsersRequest muteUsersRequest) Future<MuteUsersResponse?>
Mute users
muteUsersWithHttpInfo(String type, String id, MuteUsersRequest muteUsersRequest) Future<Response>
Mute users
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAggregateCallStats(QueryAggregateCallStatsRequest queryAggregateCallStatsRequest) Future<QueryAggregateCallStatsResponse?>
Query Aggregate call Stats
queryAggregateCallStatsWithHttpInfo(QueryAggregateCallStatsRequest queryAggregateCallStatsRequest) Future<Response>
Query Aggregate call Stats
queryCallMembers(QueryCallMembersRequest queryCallMembersRequest) Future<QueryCallMembersResponse?>
Query call members
queryCallMembersWithHttpInfo(QueryCallMembersRequest queryCallMembersRequest) Future<Response>
Query call members
queryCallParticipants(String id, String type, QueryCallParticipantsRequest queryCallParticipantsRequest, {int? limit}) Future<QueryCallParticipantsResponse?>
Query call participants
queryCallParticipantSessions(String type, String id, String session, {int? limit, String? prev, String? next, Map<String, Object>? filterConditions}) Future<QueryCallParticipantSessionsResponse?>
Query call participant sessions
queryCallParticipantSessionsWithHttpInfo(String type, String id, String session, {int? limit, String? prev, String? next, Map<String, Object>? filterConditions}) Future<Response>
Query call participant sessions
queryCallParticipantsWithHttpInfo(String id, String type, QueryCallParticipantsRequest queryCallParticipantsRequest, {int? limit}) Future<Response>
Query call participants
queryCalls(QueryCallsRequest queryCallsRequest, {String? connectionId}) Future<QueryCallsResponse?>
Query call
queryCallSessionParticipantStats(String callType, String callId, String session, {List<SortParamRequest>? sort, Map<String, Object>? filterConditions, int? limit, String? prev, String? next}) Future<QueryCallSessionParticipantStatsResponse?>
Query call participant statistics
queryCallSessionParticipantStatsWithHttpInfo(String callType, String callId, String session, {List<SortParamRequest>? sort, Map<String, Object>? filterConditions, int? limit, String? prev, String? next}) Future<Response>
Query call participant statistics
queryCallStats(QueryCallStatsRequest queryCallStatsRequest) Future<QueryCallStatsResponse?>
Query Call Stats
queryCallStatsWithHttpInfo(QueryCallStatsRequest queryCallStatsRequest) Future<Response>
Query Call Stats
queryCallsWithHttpInfo(QueryCallsRequest queryCallsRequest, {String? connectionId}) Future<Response>
Query call
rejectCall(String type, String id, RejectCallRequest rejectCallRequest) Future<RejectCallResponse?>
Reject Call
rejectCallWithHttpInfo(String type, String id, RejectCallRequest rejectCallRequest) Future<Response>
Reject Call
requestPermission(String type, String id, RequestPermissionRequest requestPermissionRequest) Future<RequestPermissionResponse?>
Request permission
requestPermissionWithHttpInfo(String type, String id, RequestPermissionRequest requestPermissionRequest) Future<Response>
Request permission
resolveSipAuth(ResolveSipAuthRequest resolveSipAuthRequest) Future<ResolveSipAuthResponse?>
Resolve SIP Auth
resolveSipAuthWithHttpInfo(ResolveSipAuthRequest resolveSipAuthRequest) Future<Response>
Resolve SIP Auth
resolveSipInbound(ResolveSipInboundRequest resolveSipInboundRequest) Future<ResolveSipInboundResponse?>
Resolve SIP Inbound Routing
resolveSipInboundWithHttpInfo(ResolveSipInboundRequest resolveSipInboundRequest) Future<Response>
Resolve SIP Inbound Routing
ringCall(String type, String id, RingCallRequest ringCallRequest) Future<RingCallResponse?>
Ring Call Users
ringCallWithHttpInfo(String type, String id, RingCallRequest ringCallRequest) Future<Response>
Ring Call Users
sendCallEvent(String type, String id, SendCallEventRequest sendCallEventRequest) Future<SendCallEventResponse?>
Send custom event
sendCallEventWithHttpInfo(String type, String id, SendCallEventRequest sendCallEventRequest) Future<Response>
Send custom event
sendVideoReaction(String type, String id, SendVideoReactionRequest sendVideoReactionRequest) Future<SendVideoReactionResponse?>
Send reaction to the call
sendVideoReactionWithHttpInfo(String type, String id, SendVideoReactionRequest sendVideoReactionRequest) Future<Response>
Send reaction to the call
startClosedCaptions(String type, String id, StartClosedCaptionsRequest startClosedCaptionsRequest) Future<StartClosedCaptionsResponse?>
Start closed captions
startClosedCaptionsWithHttpInfo(String type, String id, StartClosedCaptionsRequest startClosedCaptionsRequest) Future<Response>
Start closed captions
startFrameRecording(String type, String id, StartFrameRecordingRequest startFrameRecordingRequest) Future<StartFrameRecordingResponse?>
Start frame recording
startFrameRecordingWithHttpInfo(String type, String id, StartFrameRecordingRequest startFrameRecordingRequest) Future<Response>
Start frame recording
startHLSBroadcasting(String type, String id) Future<StartHLSBroadcastingResponse?>
Start HLS broadcasting
startHLSBroadcastingWithHttpInfo(String type, String id) Future<Response>
Start HLS broadcasting
startRecording(String type, String id, String recordingType, StartRecordingRequest startRecordingRequest) Future<StartRecordingResponse?>
Start recording
startRecordingWithHttpInfo(String type, String id, String recordingType, StartRecordingRequest startRecordingRequest) Future<Response>
Start recording
startRTMPBroadcasts(String type, String id, StartRTMPBroadcastsRequest startRTMPBroadcastsRequest) Future<StartRTMPBroadcastsResponse?>
Start RTMP broadcasts
startRTMPBroadcastsWithHttpInfo(String type, String id, StartRTMPBroadcastsRequest startRTMPBroadcastsRequest) Future<Response>
Start RTMP broadcasts
startTranscription(String type, String id, StartTranscriptionRequest startTranscriptionRequest) Future<StartTranscriptionResponse?>
Start transcription
startTranscriptionWithHttpInfo(String type, String id, StartTranscriptionRequest startTranscriptionRequest) Future<Response>
Start transcription
stopAllRTMPBroadcasts(String type, String id) Future<StopAllRTMPBroadcastsResponse?>
Stop all RTMP broadcasts for a call
stopAllRTMPBroadcastsWithHttpInfo(String type, String id) Future<Response>
Stop all RTMP broadcasts for a call
stopClosedCaptions(String type, String id, StopClosedCaptionsRequest stopClosedCaptionsRequest) Future<StopClosedCaptionsResponse?>
Stop closed captions
stopClosedCaptionsWithHttpInfo(String type, String id, StopClosedCaptionsRequest stopClosedCaptionsRequest) Future<Response>
Stop closed captions
stopFrameRecording(String type, String id) Future<StopFrameRecordingResponse?>
Stop frame recording
stopFrameRecordingWithHttpInfo(String type, String id) Future<Response>
Stop frame recording
stopHLSBroadcasting(String type, String id) Future<StopHLSBroadcastingResponse?>
Stop HLS broadcasting
stopHLSBroadcastingWithHttpInfo(String type, String id) Future<Response>
Stop HLS broadcasting
stopLive(String type, String id, StopLiveRequest stopLiveRequest) Future<StopLiveResponse?>
Set call as not live
stopLiveWithHttpInfo(String type, String id, StopLiveRequest stopLiveRequest) Future<Response>
Set call as not live
stopRecording(String type, String id, String recordingType, Object body) Future<StopRecordingResponse?>
Stop recording
stopRecordingWithHttpInfo(String type, String id, String recordingType, Object body) Future<Response>
Stop recording
stopRTMPBroadcast(String type, String id, String name, Object body) Future<StopRTMPBroadcastsResponse?>
Stop RTMP broadcasts
stopRTMPBroadcastWithHttpInfo(String type, String id, String name, Object body) Future<Response>
Stop RTMP broadcasts
stopTranscription(String type, String id, StopTranscriptionRequest stopTranscriptionRequest) Future<StopTranscriptionResponse?>
Stop transcription
stopTranscriptionWithHttpInfo(String type, String id, StopTranscriptionRequest stopTranscriptionRequest) Future<Response>
Stop transcription
toString() String
A string representation of this object.
inherited
unblockUser(String type, String id, UnblockUserRequest unblockUserRequest) Future<UnblockUserResponse?>
Unblocks user on a call
unblockUserWithHttpInfo(String type, String id, UnblockUserRequest unblockUserRequest) Future<Response>
Unblocks user on a call
updateCall(String type, String id, UpdateCallRequest updateCallRequest) Future<UpdateCallResponse?>
Update Call
updateCallMembers(String type, String id, UpdateCallMembersRequest updateCallMembersRequest) Future<UpdateCallMembersResponse?>
Update Call Member
updateCallMembersWithHttpInfo(String type, String id, UpdateCallMembersRequest updateCallMembersRequest) Future<Response>
Update Call Member
updateCallWithHttpInfo(String type, String id, UpdateCallRequest updateCallRequest) Future<Response>
Update Call
updateUserPermissions(String type, String id, UpdateUserPermissionsRequest updateUserPermissionsRequest) Future<UpdateUserPermissionsResponse?>
Update user permissions
updateUserPermissionsWithHttpInfo(String type, String id, UpdateUserPermissionsRequest updateUserPermissionsRequest) Future<Response>
Update user permissions
videoConnect() Future<void>
Video Connect (WebSocket)
videoConnectWithHttpInfo() Future<Response>
Video Connect (WebSocket)
videoPin(String type, String id, PinRequest pinRequest) Future<PinResponse?>
Pin
videoPinWithHttpInfo(String type, String id, PinRequest pinRequest) Future<Response>
Pin
videoUnpin(String type, String id, UnpinRequest unpinRequest) Future<UnpinResponse?>
Unpin
videoUnpinWithHttpInfo(String type, String id, UnpinRequest unpinRequest) Future<Response>
Unpin

Operators

operator ==(Object other) bool
The equality operator.
inherited