resolveSipInbound method
Future<ResolveSipInboundResponse?>
resolveSipInbound(
- ResolveSipInboundRequest resolveSipInboundRequest
Resolve SIP Inbound Routing
Resolve SIP inbound routing based on trunk number, caller number, and challenge authentication
Parameters:
- ResolveSipInboundRequest resolveSipInboundRequest (required): ResolveSipInboundRequest
Implementation
Future<ResolveSipInboundResponse?> resolveSipInbound(
ResolveSipInboundRequest resolveSipInboundRequest,
) async {
final response = await resolveSipInboundWithHttpInfo(
resolveSipInboundRequest,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'ResolveSipInboundResponse',
) as ResolveSipInboundResponse;
}
return null;
}