PublishedTrackMetrics class

Constructors

PublishedTrackMetrics({MetricTimeSeries? bitrate, String? codec, MetricTimeSeries? framerate, ResolutionMetricsTimeSeries? resolution, String? trackId, String? trackType, List<SessionWarningResponse> warnings = const []})
Returns a new PublishedTrackMetrics instance.

Properties

bitrate MetricTimeSeries?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
codec String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
framerate MetricTimeSeries?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
resolution ResolutionMetricsTimeSeries?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackId String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
trackType String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
warnings List<SessionWarningResponse>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PublishedTrackMetrics?
Returns a new PublishedTrackMetrics instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PublishedTrackMetrics>
mapFromJson(dynamic json) Map<String, PublishedTrackMetrics>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PublishedTrackMetrics>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.