QueryCallParticipantSessionsResponse class

Constructors

QueryCallParticipantSessionsResponse({required String callId, required String callSessionId, required String callType, required int duration, String? next, List<ParticipantSessionDetails> participantsSessions = const [], String? prev, CallSessionResponse? session, required int totalParticipantDuration, required int totalParticipantSessions})
Returns a new QueryCallParticipantSessionsResponse instance.

Properties

callId String
getter/setter pair
callSessionId String
getter/setter pair
callType String
getter/setter pair
duration int
Duration of the request in milliseconds
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
next String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
participantsSessions List<ParticipantSessionDetails>
getter/setter pair
prev String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session CallSessionResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
totalParticipantDuration int
getter/setter pair
totalParticipantSessions int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) QueryCallParticipantSessionsResponse?
Returns a new QueryCallParticipantSessionsResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<QueryCallParticipantSessionsResponse>
mapFromJson(dynamic json) Map<String, QueryCallParticipantSessionsResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<QueryCallParticipantSessionsResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.