QueryCallSessionParticipantStatsResponse class

Constructors

QueryCallSessionParticipantStatsResponse({DateTime? callEndedAt, List<CallLevelEventPayload> callEvents = const [], required String callId, required String callSessionId, DateTime? callStartedAt, required String callType, required CallStatsParticipantCounts counts, required String duration, String? next, List<CallStatsParticipant> participants = const [], String? prev, String? tmpDataSource})
Returns a new QueryCallSessionParticipantStatsResponse instance.

Properties

callEndedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
callEvents List<CallLevelEventPayload>
getter/setter pair
callId String
getter/setter pair
callSessionId String
getter/setter pair
callStartedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
callType String
getter/setter pair
counts CallStatsParticipantCounts
getter/setter pair
duration String
Duration of the request in milliseconds
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
next String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
participants List<CallStatsParticipant>
getter/setter pair
prev String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tmpDataSource String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) QueryCallSessionParticipantStatsResponse?
Returns a new QueryCallSessionParticipantStatsResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<QueryCallSessionParticipantStatsResponse>
mapFromJson(dynamic json) Map<String, QueryCallSessionParticipantStatsResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<QueryCallSessionParticipantStatsResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.