QueryCallSessionParticipantStatsTimelineResponse class

Constructors

QueryCallSessionParticipantStatsTimelineResponse({required String callId, required String callSessionId, required String callType, required String duration, List<CallParticipantTimeline> events = const [], required String userId, required String userSessionId})
Returns a new QueryCallSessionParticipantStatsTimelineResponse instance.

Properties

callId String
getter/setter pair
callSessionId String
getter/setter pair
callType String
getter/setter pair
duration String
Duration of the request in milliseconds
getter/setter pair
events List<CallParticipantTimeline>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
getter/setter pair
userSessionId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) QueryCallSessionParticipantStatsTimelineResponse?
Returns a new QueryCallSessionParticipantStatsTimelineResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<QueryCallSessionParticipantStatsTimelineResponse>
mapFromJson(dynamic json) Map<String, QueryCallSessionParticipantStatsTimelineResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<QueryCallSessionParticipantStatsTimelineResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.