RTMPSettingsRequest class

Constructors

RTMPSettingsRequest({bool? enabled, RTMPSettingsRequestQualityEnum? quality})
Returns a new RTMPSettingsRequest instance.

Properties

enabled bool?
Whether RTMP broadcasting is enabled
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
quality RTMPSettingsRequestQualityEnum?
Resolution to set for the RTMP stream. One of: 360p, 480p, 720p, 1080p, 1440p, portrait-360x640, portrait-480x854, portrait-720x1280, portrait-1080x1920, portrait-1440x2560
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RTMPSettingsRequest?
Returns a new RTMPSettingsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RTMPSettingsRequest>
mapFromJson(dynamic json) Map<String, RTMPSettingsRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RTMPSettingsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.