ResolveSipAuthRequest class
Constructors
- ResolveSipAuthRequest({String? fromHost, required String sipCallerNumber, required String sipTrunkNumber, String? sourceIp})
- Returns a new ResolveSipAuthRequest instance.
Properties
- fromHost ↔ String?
-
Host from the SIP From header
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sipCallerNumber ↔ String
-
SIP caller number
getter/setter pair
- sipTrunkNumber ↔ String
-
SIP trunk number to look up
getter/setter pair
- sourceIp ↔ String?
-
Transport-layer source IP address of the SIP request
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ResolveSipAuthRequest? -
Returns a new ResolveSipAuthRequest instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ResolveSipAuthRequest> -
mapFromJson(
dynamic json) → Map< String, ResolveSipAuthRequest> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ResolveSipAuthRequest> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.