ResolveSipAuthResponse class

Constructors

ResolveSipAuthResponse({required String authResult, required String duration, String? password, String? trunkId, String? username})
Returns a new ResolveSipAuthResponse instance.

Properties

authResult String
Authentication result: password, accept, or no_trunk_found
getter/setter pair
duration String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
password String?
Password for digest authentication (when auth_result is password)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trunkId String?
ID of the matched SIP trunk
getter/setter pair
username String?
Username for digest authentication (when auth_result is password)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ResolveSipAuthResponse?
Returns a new ResolveSipAuthResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ResolveSipAuthResponse>
mapFromJson(dynamic json) Map<String, ResolveSipAuthResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ResolveSipAuthResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.