ResolveSipInboundRequest class

Constructors

ResolveSipInboundRequest({SIPChallengeRequest? challenge, String? routingNumber, required String sipCallerNumber, Map<String, String> sipHeaders = const {}, required String sipTrunkNumber, String? trunkId})
Returns a new ResolveSipInboundRequest instance.

Properties

challenge SIPChallengeRequest?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
routingNumber String?
Optional routing number for routing number-based call routing (10 digits)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sipCallerNumber String
SIP caller number
getter/setter pair
sipHeaders Map<String, String>
Optional SIP headers as key-value pairs
getter/setter pair
sipTrunkNumber String
SIP trunk number to resolve
getter/setter pair
trunkId String?
Optional pre-authenticated trunk ID (from PreAuth no-auth flow)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ResolveSipInboundRequest?
Returns a new ResolveSipInboundRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ResolveSipInboundRequest>
mapFromJson(dynamic json) Map<String, ResolveSipInboundRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ResolveSipInboundRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.