SIPCallConfigsResponse class
Constructors
-
SIPCallConfigsResponse({Map<
String, Object> customData = const {}}) - Returns a new SIPCallConfigsResponse instance.
Properties
-
customData
↔ Map<
String, Object> -
Custom data associated with the call
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SIPCallConfigsResponse? -
Returns a new SIPCallConfigsResponse instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SIPCallConfigsResponse> -
mapFromJson(
dynamic json) → Map< String, SIPCallConfigsResponse> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SIPCallConfigsResponse> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.