SIPChallengeRequest class

Constructors

SIPChallengeRequest({String? a1, String? algorithm, String? charset, String? cnonce, List<String> domain = const [], String? method, String? nc, String? nonce, String? opaque, List<String> qop = const [], String? realm, String? response, bool? stale, String? uri, bool? userhash, String? username})
Returns a new SIPChallengeRequest instance.

Properties

a1 String?
Deprecated: A1 hash for backward compatibility
getter/setter pair
algorithm String?
Hash algorithm (e.g., MD5, SHA-256)
getter/setter pair
charset String?
Character set
getter/setter pair
cnonce String?
Client nonce for qop=auth
getter/setter pair
domain List<String>
Domain list
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
method String?
SIP method (e.g., INVITE)
getter/setter pair
nc String?
Nonce count for qop=auth
getter/setter pair
nonce String?
Server nonce
getter/setter pair
opaque String?
Opaque value
getter/setter pair
qop List<String>
Quality of protection options
getter/setter pair
realm String?
Authentication realm
getter/setter pair
response String?
Digest response hash from client
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale bool?
Whether the nonce is stale
getter/setter pair
uri String?
Request URI
getter/setter pair
userhash bool?
Whether to hash the username
getter/setter pair
username String?
Username for authentication
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SIPChallengeRequest?
Returns a new SIPChallengeRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SIPChallengeRequest>
mapFromJson(dynamic json) Map<String, SIPChallengeRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SIPChallengeRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.