SIPInboundRoutingRuleResponse class

Constructors

SIPInboundRoutingRuleResponse({SIPCallConfigsResponse? callConfigs, List<String> calledNumbers = const [], SIPCallerConfigsResponse? callerConfigs, List<String> callerNumbers = const [], required DateTime createdAt, SIPDirectRoutingRuleCallConfigsResponse? directRoutingConfigs, required String duration, required String id, required String name, SIPPinProtectionConfigsResponse? pinProtectionConfigs, SIPInboundRoutingRulePinConfigsResponse? pinRoutingConfigs, List<String> trunkIds = const [], required DateTime updatedAt})
Returns a new SIPInboundRoutingRuleResponse instance.

Properties

callConfigs SIPCallConfigsResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
calledNumbers List<String>
List of called numbers
getter/setter pair
callerConfigs SIPCallerConfigsResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
callerNumbers List<String>
List of caller numbers
getter/setter pair
createdAt DateTime
Creation timestamp
getter/setter pair
directRoutingConfigs SIPDirectRoutingRuleCallConfigsResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
duration String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier of the SIP Inbound Routing Rule
getter/setter pair
name String
Name of the SIP Inbound Routing Rule
getter/setter pair
pinProtectionConfigs SIPPinProtectionConfigsResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
pinRoutingConfigs SIPInboundRoutingRulePinConfigsResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trunkIds List<String>
List of SIP trunk IDs
getter/setter pair
updatedAt DateTime
Last update timestamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SIPInboundRoutingRuleResponse?
Returns a new SIPInboundRoutingRuleResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SIPInboundRoutingRuleResponse>
mapFromJson(dynamic json) Map<String, SIPInboundRoutingRuleResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SIPInboundRoutingRuleResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.