SIPTrunkResponse class

Constructors

SIPTrunkResponse({List<String> allowedIps = const [], required DateTime createdAt, required String id, required String name, List<String> numbers = const [], required String password, required DateTime updatedAt, required String uri, required String username})
Returns a new SIPTrunkResponse instance.

Properties

allowedIps List<String>
Allowed IPv4/IPv6 addresses or CIDR blocks
getter/setter pair
createdAt DateTime
Creation timestamp
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier for the SIP trunk
getter/setter pair
name String
Name of the SIP trunk
getter/setter pair
numbers List<String>
Phone numbers associated with this SIP trunk
getter/setter pair
password String
Password for SIP trunk authentication
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
Last update timestamp
getter/setter pair
uri String
The URI for the SIP trunk
getter/setter pair
username String
Username for SIP trunk authentication
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SIPTrunkResponse?
Returns a new SIPTrunkResponse instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SIPTrunkResponse>
mapFromJson(dynamic json) Map<String, SIPTrunkResponse>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SIPTrunkResponse>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.