SipInboundCredentials class

Constructors

SipInboundCredentials({required String apiKey, Map<String, Object> callCustomData = const {}, required String callId, required String callType, required String token, Map<String, Object> userCustomData = const {}, required String userId})
Returns a new SipInboundCredentials instance.

Properties

apiKey String
API key for the application
getter/setter pair
callCustomData Map<String, Object>
Custom data associated with the call
getter/setter pair
callId String
ID of the call
getter/setter pair
callType String
Type of the call
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Authentication token for the call
getter/setter pair
userCustomData Map<String, Object>
Custom data associated with the user
getter/setter pair
userId String
User ID for the call
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SipInboundCredentials?
Returns a new SipInboundCredentials instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SipInboundCredentials>
mapFromJson(dynamic json) Map<String, SipInboundCredentials>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SipInboundCredentials>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.