StartClosedCaptionsRequest class

Constructors

StartClosedCaptionsRequest({bool? enableTranscription, String? externalStorage, StartClosedCaptionsRequestLanguageEnum? language, SpeechSegmentConfig? speechSegmentConfig})
Returns a new StartClosedCaptionsRequest instance.

Properties

enableTranscription bool?
Enable transcriptions along with closed captions
getter/setter pair
externalStorage String?
Which external storage to use for transcriptions (only applicable if enable_transcription is true)
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
language StartClosedCaptionsRequestLanguageEnum?
The spoken language in the call, if not provided the language defined in the transcription settings will be used. One of: auto, ar, bg, ca, cs, da, de, el, en, es, et, fi, fr, he, hi, hr, hu, id, it, ja, ko, ms, nl, no, pl, pt, ro, ru, sk, sl, sv, ta, th, tl, tr, uk, zh
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speechSegmentConfig SpeechSegmentConfig?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StartClosedCaptionsRequest?
Returns a new StartClosedCaptionsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StartClosedCaptionsRequest>
mapFromJson(dynamic json) Map<String, StartClosedCaptionsRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StartClosedCaptionsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.