UserDeletedEvent class
Constructors
UserDeletedEvent ({required DateTime createdAt , Map <String , Object > custom = const {} , required String deleteConversation , required bool deleteConversationChannels , required String deleteMessages , required String deleteUser , required bool hardDelete , required bool markMessagesDeleted , DateTime ? receivedAt , String type = 'user.deleted' , required UserResponseCommonFields user })
Returns a new UserDeletedEvent instance.
Properties
createdAt
↔ DateTime
Date/time of creation
getter/setter pair
custom
↔ Map <String , Object >
getter/setter pair
deleteConversation
↔ String
The type of deletion that was used for the user's conversations. One of: hard, soft, pruning, (empty string)
getter/setter pair
deleteConversationChannels
↔ bool
Whether the user's conversation channels were deleted
getter/setter pair
deleteMessages
↔ String
The type of deletion that was used for the user's messages. One of: hard, soft, pruning, (empty string)
getter/setter pair
deleteUser
↔ String
The type of deletion that was used for the user. One of: hard, soft, pruning, (empty string)
getter/setter pair
hardDelete
↔ bool
Whether the user was hard deleted
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter override
markMessagesDeleted
↔ bool
Whether the user's messages were marked as deleted
getter/setter pair
receivedAt
↔ DateTime ?
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
type
↔ String
The type of event: "user.deleted" in this case
getter/setter pair
user
↔ UserResponseCommonFields
getter/setter pair