deleteConversation property
The type of deletion that was used for the user's conversations. One of: hard, soft, pruning, (empty string)
Implementation
String deleteConversation;
The type of deletion that was used for the user's conversations. One of: hard, soft, pruning, (empty string)
String deleteConversation;