deleteMessages property
The type of deletion that was used for the user's messages. One of: hard, soft, pruning, (empty string)
Implementation
String deleteMessages;
The type of deletion that was used for the user's messages. One of: hard, soft, pruning, (empty string)
String deleteMessages;