deleteUser property
The type of deletion that was used for the user. One of: hard, soft, pruning, (empty string)
Implementation
String deleteUser;
The type of deletion that was used for the user. One of: hard, soft, pruning, (empty string)
String deleteUser;