UserUnbannedEvent class

Constructors

UserUnbannedEvent({Map<String, Object> channelCustom = const {}, String? channelId, int? channelMemberCount, int? channelMessageCount, String? channelType, String? cid, required DateTime createdAt, UserResponseCommonFields? createdBy, Map<String, Object> custom = const {}, DateTime? receivedAt, bool? shadow, String? team, String type = 'user.unbanned', required UserResponseCommonFields user})
Returns a new UserUnbannedEvent instance.

Properties

channelCustom Map<String, Object>
getter/setter pair
channelId String?
The ID of the channel where the target user was unbanned
getter/setter pair
channelMemberCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
channelMessageCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
channelType String?
The type of the channel where the target user was unbanned
getter/setter pair
cid String?
The CID of the channel where the target user was unbanned
getter/setter pair
createdAt DateTime
Date/time of creation
getter/setter pair
createdBy UserResponseCommonFields?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
custom Map<String, Object>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
receivedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow bool?
Whether the target user was shadow unbanned
getter/setter pair
team String?
The team of the channel where the target user was unbanned
getter/setter pair
type String
The type of event: "user.unbanned" in this case
getter/setter pair
user UserResponseCommonFields
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UserUnbannedEvent?
Returns a new UserUnbannedEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UserUnbannedEvent>
mapFromJson(dynamic json) Map<String, UserUnbannedEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UserUnbannedEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.