VideoEvent class

Constructors

VideoEvent({required AppEventResponse app, required DateTime createdAt, Map<String, Object> custom = const {}, DateTime? receivedAt, String type = 'user.updated', UserResponse? blockedByUser, required String callCid, required UserResponsePrivacyFields user, required CallResponse call, List<MemberResponse> members = const [], required String digit, required int durationMs, required int seqNumber, required DateTime timestamp, required String reason, required String egressId, required DateTime capturedAt, required String sessionId, required String trackType, required String url, Map<String, UserResponse> users = const {}, required String hlsPlaylistUrl, Map<String, List<String>> capabilitiesByRole = const {}, required bool notifyUser, required String userId, required String message, required VideoReactionResponse reaction, required VideoEventRecordingTypeEnum recordingType, required CallRecording callRecording, required bool video, required String name, required int anonymousParticipantCount, Map<String, int> participantsCountByRole = const {}, required CallParticipantResponse participant, required int durationSeconds, bool? isTrimmed, List<CallStatsParticipant> participantsOverview = const [], required String error, required CallTranscription callTranscription, required int rating, String? sdk, String? sdkVersion, required String fromUserId, List<String> mutedUserIds = const [], required CallClosedCaption closedCaption, required String connectionId, required OwnUserResponse me, String? cid, String? code, required String ingressStreamId, String? clientIp, String? clientName, required String publisherType, String? version, UserResponse? kickedByUser, List<String> permissions = const [], List<OwnCapability> ownCapabilities = const [], Map<String, Object> channelCustom = const {}, String? channelId, int? channelMemberCount, int? channelMessageCount, String? channelType, UserResponseCommonFields? createdBy, DateTime? expiration, bool? shadow, String? team, int? totalBans, required String deleteConversation, required bool deleteConversationChannels, required String deleteMessages, required String deleteUser, required bool hardDelete, required bool markMessagesDeleted})
Returns a new VideoEvent instance.

Properties

anonymousParticipantCount int
getter/setter pair
app AppEventResponse
getter/setter pair
blockedByUser UserResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
call CallResponse
getter/setter pair
callCid String
getter/setter pair
callRecording CallRecording
getter/setter pair
callTranscription CallTranscription
getter/setter pair
capabilitiesByRole Map<String, List<String>>
The capabilities by role for this call
getter/setter pair
capturedAt DateTime
The time the frame was captured
getter/setter pair
channelCustom Map<String, Object>
getter/setter pair
channelId String?
The ID of the channel where the target user was unbanned
getter/setter pair
channelMemberCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
channelMessageCount int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
channelType String?
The type of the channel where the target user was unbanned
getter/setter pair
cid String?
The CID of the channel where the target user was unbanned
getter/setter pair
clientIp String?
Client IP address
getter/setter pair
clientName String?
Streaming client software name (e.g., 'OBS Studio')
getter/setter pair
closedCaption CallClosedCaption
getter/setter pair
code String?
Error code
getter/setter pair
connectionId String
getter/setter pair
createdAt DateTime
Date/time of creation
getter/setter pair
createdBy UserResponseCommonFields?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
custom Map<String, Object>
getter/setter pair
deleteConversation String
The type of deletion that was used for the user's conversations. One of: hard, soft, pruning, (empty string)
getter/setter pair
deleteConversationChannels bool
Whether the user's conversation channels were deleted
getter/setter pair
deleteMessages String
The type of deletion that was used for the user's messages. One of: hard, soft, pruning, (empty string)
getter/setter pair
deleteUser String
The type of deletion that was used for the user. One of: hard, soft, pruning, (empty string)
getter/setter pair
digit String
The DTMF digit (0-9, *, #, A-D)
getter/setter pair
durationMs int
Duration of the digit press in milliseconds
getter/setter pair
durationSeconds int
The duration participant was in the session in seconds
getter/setter pair
egressId String
getter/setter pair
error String
Human-readable error message
getter/setter pair
expiration DateTime?
The expiration date of the ban
getter/setter pair
fromUserId String
getter/setter pair
hardDelete bool
Whether the user was hard deleted
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hlsPlaylistUrl String
getter/setter pair
ingressStreamId String
Unique identifier for the stream
getter/setter pair
isTrimmed bool?
Whether participants_overview is truncated by the server-side limit
getter/setter pair
kickedByUser UserResponse?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
markMessagesDeleted bool
Whether the user's messages were marked as deleted
getter/setter pair
me OwnUserResponse
getter/setter pair
members List<MemberResponse>
Call members
getter/setter pair
message String
The warning message
getter/setter pair
mutedUserIds List<String>
getter/setter pair
name String
Name of the given RTMP broadcast
getter/setter pair
notifyUser bool
getter/setter pair
ownCapabilities List<OwnCapability>
The capabilities of the current user
getter/setter pair
participant CallParticipantResponse
getter/setter pair
participantsCountByRole Map<String, int>
getter/setter pair
participantsOverview List<CallStatsParticipant>
Top participant sessions overview
getter/setter pair
permissions List<String>
The list of permissions requested by the user
getter/setter pair
publisherType String
Streaming protocol (e.g., 'rtmps', 'srt', 'rtmp', 'rtsp')
getter/setter pair
rating int
The rating given by the user (1-5)
getter/setter pair
reaction VideoReactionResponse
getter/setter pair
reason String
The reason for the ban
getter/setter pair
receivedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
recordingType VideoEventRecordingTypeEnum
The type of recording
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdk String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
sdkVersion String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
seqNumber int
Monotonically increasing sequence number for ordering DTMF events within a session
getter/setter pair
sessionId String
Call session ID
getter/setter pair
shadow bool?
Whether the target user was shadow unbanned
getter/setter pair
team String?
The team of the channel where the target user was unbanned
getter/setter pair
timestamp DateTime
When the digit press ended and was detected
getter/setter pair
totalBans int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
trackType String
The type of the track frame was captured from (TRACK_TYPE_VIDEO|TRACK_TYPE_SCREEN_SHARE)
getter/setter pair
type String
The type of event: "user.updated" in this case
getter/setter pair
url String
The URL of the frame
getter/setter pair
user UserResponsePrivacyFields
getter/setter pair
userId String
User who was streaming
getter/setter pair
users Map<String, UserResponse>
The users in the frame
getter/setter pair
version String?
Client software version
getter/setter pair
video bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) VideoEvent?
Returns a new VideoEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<VideoEvent>
mapFromJson(dynamic json) Map<String, VideoEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<VideoEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.