WHIPIngress class

Constructors

WHIPIngress({required String address})
Returns a new WHIPIngress instance.

Properties

address String
URL for a new whip input, every time a new link is created
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WHIPIngress?
Returns a new WHIPIngress instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WHIPIngress>
mapFromJson(dynamic json) Map<String, WHIPIngress>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WHIPIngress>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.