WSCallEvent class

Constructors

WSCallEvent({required String callCid, required DateTime createdAt, required String digit, required int durationMs, required int seqNumber, required DateTime timestamp, String type = 'ingress.stopped', required UserResponse user, String? code, required String error, required String ingressStreamId, required String userId, String? clientIp, String? clientName, required String publisherType, String? version})
Returns a new WSCallEvent instance.

Properties

callCid String
getter/setter pair
clientIp String?
Client IP address
getter/setter pair
clientName String?
Streaming client software name (e.g., 'OBS Studio')
getter/setter pair
code String?
Error code
getter/setter pair
createdAt DateTime
getter/setter pair
digit String
The DTMF digit (0-9, *, #, A-D)
getter/setter pair
durationMs int
Duration of the digit press in milliseconds
getter/setter pair
error String
Human-readable error message
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
ingressStreamId String
Unique identifier for the stream
getter/setter pair
publisherType String
Streaming protocol (e.g., 'rtmps', 'srt', 'rtmp', 'rtsp')
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seqNumber int
Monotonically increasing sequence number for ordering DTMF events within a session
getter/setter pair
timestamp DateTime
When the digit press ended and was detected
getter/setter pair
type String
The type of event: "ingress.stopped" in this case
getter/setter pair
user UserResponse
getter/setter pair
userId String
User who was streaming
getter/setter pair
version String?
Client software version
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WSCallEvent?
Returns a new WSCallEvent instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WSCallEvent>
mapFromJson(dynamic json) Map<String, WSCallEvent>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WSCallEvent>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.