CallDTMFEvent class
Constructors
- CallDTMFEvent({required String callCid, required DateTime createdAt, required String digit, required int durationMs, required int seqNumber, required DateTime timestamp, String type = 'call.dtmf', required UserResponse user})
- Returns a new CallDTMFEvent instance.
Properties
- callCid ↔ String
-
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- digit ↔ String
-
The DTMF digit (0-9, *, #, A-D)
getter/setter pair
- durationMs ↔ int
-
Duration of the digit press in milliseconds
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seqNumber ↔ int
-
Monotonically increasing sequence number for ordering DTMF events within a session
getter/setter pair
- timestamp ↔ DateTime
-
When the digit press ended and was detected
getter/setter pair
- type ↔ String
-
The type of event: "call.dtmf" in this case
getter/setter pair
- user ↔ UserResponse
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CallDTMFEvent? -
Returns a new CallDTMFEvent instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CallDTMFEvent> -
mapFromJson(
dynamic json) → Map< String, CallDTMFEvent> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CallDTMFEvent> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.