IngressErrorEvent class
Constructors
- IngressErrorEvent({required String callCid, String? code, required DateTime createdAt, required String error, required String ingressStreamId, String type = 'ingress.error', required String userId})
- Returns a new IngressErrorEvent instance.
Properties
- callCid ↔ String
-
getter/setter pair
- code ↔ String?
-
Error code
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- error ↔ String
-
Human-readable error message
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- ingressStreamId ↔ String
-
Unique identifier for the stream
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
The type of event: "ingress.error" in this case
getter/setter pair
- userId ↔ String
-
User who was streaming
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → IngressErrorEvent? -
Returns a new IngressErrorEvent instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< IngressErrorEvent> -
mapFromJson(
dynamic json) → Map< String, IngressErrorEvent> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< IngressErrorEvent> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.