IngressStartedEvent class
Constructors
Properties
- callCid ↔ String
-
getter/setter pair
- clientIp ↔ String?
-
Client IP address
getter/setter pair
- clientName ↔ String?
-
Streaming client software name (e.g., 'OBS Studio')
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- ingressStreamId ↔ String
-
Unique identifier for this stream
getter/setter pair
- publisherType ↔ String
-
Streaming protocol (e.g., 'rtmps', 'srt', 'rtmp', 'rtsp')
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
The type of event: "ingress.started" in this case
getter/setter pair
- userId ↔ String
-
User who started the stream
getter/setter pair
- version ↔ String?
-
Client software version
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → IngressStartedEvent? -
Returns a new IngressStartedEvent instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< IngressStartedEvent> -
mapFromJson(
dynamic json) → Map< String, IngressStartedEvent> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< IngressStartedEvent> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.