ParticipantSeriesSubscriberStats class
Constructors
-
ParticipantSeriesSubscriberStats({Map<
String, List< global = const {}, Map<List< >double> >String, MetricDescriptor> globalMeta = const {}, List<String> globalMetricsOrder = const [], Map<String, List< globalThresholds = const {}, List<MetricThreshold> >ParticipantSeriesSubscriptionTrackMetrics> subscriptions = const []}) - Returns a new ParticipantSeriesSubscriberStats instance.
Properties
-
global
↔ Map<
String, List< List< >double> > -
getter/setter pair
-
globalMeta
↔ Map<
String, MetricDescriptor> -
getter/setter pair
-
globalMetricsOrder
↔ List<
String> -
getter/setter pair
-
globalThresholds
↔ Map<
String, List< MetricThreshold> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
↔ List<
ParticipantSeriesSubscriptionTrackMetrics> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ParticipantSeriesSubscriberStats? -
Returns a new ParticipantSeriesSubscriberStats instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ParticipantSeriesSubscriberStats> -
mapFromJson(
dynamic json) → Map< String, ParticipantSeriesSubscriberStats> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ParticipantSeriesSubscriberStats> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.