QueryCallParticipantSessionsResponse class
Properties
-
callId
↔ String
-
getter/setter pair
-
callSessionId
↔ String
-
getter/setter pair
-
callType
↔ String
-
getter/setter pair
-
duration
↔ int
-
Duration of the request in milliseconds
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
next
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
participantsSessions
↔ List<ParticipantSessionDetails>
-
getter/setter pair
-
prev
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
session
↔ CallSessionResponse?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
totalParticipantDuration
↔ int
-
getter/setter pair
-
totalParticipantSessions
↔ int
-
getter/setter pair