QueryCallStatsMapResponse class
Constructors
-
QueryCallStatsMapResponse({DateTime? callEndedAt, required String callId, required String callSessionId, DateTime? callStartedAt, required String callType, required CallStatsParticipantCounts counts, String? dataSource, required String duration, DateTime? endTime, DateTime? generatedAt, CallStatsMapPublishers? publishers, CallStatsMapSFUs? sfus, DateTime? startTime, CallStatsMapSubscribers? subscribers})
-
Returns a new QueryCallStatsMapResponse instance.
Properties
-
callEndedAt
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
callId
↔ String
-
getter/setter pair
-
callSessionId
↔ String
-
getter/setter pair
-
callStartedAt
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
callType
↔ String
-
getter/setter pair
-
counts
↔ CallStatsParticipantCounts
-
getter/setter pair
-
dataSource
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
duration
↔ String
-
Duration of the request in milliseconds
getter/setter pair
-
endTime
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
generatedAt
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
publishers
↔ CallStatsMapPublishers?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sfus
↔ CallStatsMapSFUs?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
startTime
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
subscribers
↔ CallStatsMapSubscribers?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair