SIPInboundRoutingRulePinConfigsResponse class
Constructors
- SIPInboundRoutingRulePinConfigsResponse({String? customWebhookUrl, String? pinFailedAttemptPrompt, String? pinHangupPrompt, String? pinPrompt, String? pinSuccessPrompt})
- Returns a new SIPInboundRoutingRulePinConfigsResponse instance.
Properties
- customWebhookUrl ↔ String?
-
Optional webhook URL for custom PIN handling
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- pinFailedAttemptPrompt ↔ String?
-
Prompt message for failed PIN attempts
getter/setter pair
- pinHangupPrompt ↔ String?
-
Prompt message for hangup after PIN input
getter/setter pair
- pinPrompt ↔ String?
-
Prompt message for PIN input
getter/setter pair
- pinSuccessPrompt ↔ String?
-
Prompt message for successful PIN input
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SIPInboundRoutingRulePinConfigsResponse? -
Returns a new SIPInboundRoutingRulePinConfigsResponse instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SIPInboundRoutingRulePinConfigsResponse> -
mapFromJson(
dynamic json) → Map< String, SIPInboundRoutingRulePinConfigsResponse> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SIPInboundRoutingRulePinConfigsResponse> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.